==> symfony_5.4.9+dfsg.orig.tar.xz: symfony-5.4.9/src/Symfony/Component/Intl/Resources/data/scripts/ca.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Afak' => 'afaka',
        'Aghb' => 'albanès caucàsic',
        'Ahom' => 'ahom',
        'Arab' => 'àrab',
        'Aran' => 'nastaliq',
        'Armi' => 'arameu imperial',
        'Armn' => 'armeni',
        'Avst' => 'avèstic',
        'Bali' => 'balinès',
        'Bamu' => 'bamum',
        'Bass' => 'bassa vah',
        'Batk' => 'batak',
        'Beng' => 'bengalí',
        'Bhks' => 'bhaiksuki',
        'Blis' => 'símbols Bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginès',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'síl·labes dels aborígens canadencs unificats',
        'Cari' => 'carià',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'copte',
        'Cprt' => 'xipriota',
        'Cyrl' => 'ciríl·lic',
        'Cyrs' => 'ciríl·lic de l’antic eslau eclesiàstic',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Dupl' => 'taquigrafia Duployé',
        'Egyd' => 'demòtic egipci',
        'Egyh' => 'hieràtic egipci',
        'Egyp' => 'jeroglífic egipci',
        'Elba' => 'elbasan',
        'Ethi' => 'etiòpic',
        'Geok' => 'georgià hucuri',
        'Geor' => 'georgià',
        'Glag' => 'glagolític',
        'Goth' => 'gòtic',
        'Gran' => 'grantha',
        'Grek' => 'grec',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han amb bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'simplificat',
        'Hant' => 'tradicional',
        'Hebr' => 'hebreu',
        'Hira' => 'hiragana',
        'Hluw' => 'jeroglífic anatoli',
        'Hmng' => 'pahawh hmong',
        'Hrkt' => 'sil·labaris japonesos',
        'Hung' => 'hongarès antic',
        'Inds' => 'escriptura de la vall de l’Indus',
        'Ital' => 'cursiva antiga',
        'Jamo' => 'jamo',
        'Java' => 'javanès',
        'Jpan' => 'japonès',
        'Jurc' => 'jürchen',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharosthi',
        'Khmr' => 'khmer',
        'Khoj' => 'khoja',
        'Knda' => 'kannada',
        'Kore' => 'coreà',
        'Kpel' => 'kpelle',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'lao',
        'Latf' => 'llatí fraktur',
        'Latg' => 'llatí gaèlic',
        'Latn' => 'llatí',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineal A',
        'Linb' => 'lineal B',
        'Lisu' => 'lisu',
        'Loma' => 'loma',
        'Lyci' => 'lici',
        'Lydi' => 'lidi',
        'Mahj' => 'mahajani',
        'Mand' => 'mandaic',
        'Mani' => 'maniqueu',
        'Maya' => 'jeroglífics maies',
        'Mend' => 'mende',
        'Merc' => 'cursiva meroítica',
        'Mero' => 'meroític',
        'Mlym' => 'malaiàlam',
        'Modi' => 'modi',
        'Mong' => 'mongol',
        'Moon' => 'moon',
        'Mroo' => 'mro',
        'Mtei' => 'manipurí',
        'Mult' => 'multani',
        'Mymr' => 'birmà',
        'Narb' => 'antic nord-aràbic',
        'Nbat' => 'nabateu',
        'Newa' => 'newar',
        'Nkgb' => 'geba',
        'Nkoo' => 'n’Ko',
        'Nshu' => 'nü shu',
        'Ogam' => 'ogham',
        'Olck' => 'santali',
        'Orkh' => 'orkhon',
        'Orya' => 'oriya',
        'Osge' => 'osage',
        'Osma' => 'osmanya',
        'Palm' => 'palmirè',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'antic pèrmic',
        'Phag' => 'phagspa',
        'Phli' => 'pahlavi inscripcional',
        'Phlp' => 'psalter pahlavi',
        'Phlv' => 'pahlavi',
        'Phnx' => 'fenici',
        'Plrd' => 'pollard miao',
        'Prti' => 'parthià inscripcional',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Roro' => 'rongo-rongo',
        'Runr' => 'rúnic',
        'Samr' => 'samarità',
        'Sara' => 'sarati',
        'Sarb' => 'sud-aràbic antic',
        'Saur' => 'saurashtra',
        'Sgnw' => 'escriptura de signes',
        'Shaw' => 'shavià',
        'Shrd' => 'shrada',
        'Sidd' => 'siddham',
        'Sind' => 'devangari',
        'Sinh' => 'singalès',
        'Sora' => 'sora sompeng',
        'Sund' => 'sundanès',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siríac',
        'Syre' => 'siríac estrangelo',
        'Syrj' => 'siríac occidental',
        'Syrn' => 'siríac oriental',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'nou tai lue',
        'Taml' => 'tàmil',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagàlog',
        'Thaa' => 'thaana',
        'Thai' => 'tailandès',
        'Tibt' => 'tibetà',
        'Tirh' => 'tirhut',
        'Ugar' => 'ugarític',
        'Vaii' => 'vai',
        'Visp' => 'llenguatge visible',
        'Wara' => 'varang kshiti',
        'Wole' => 'woleai',
        'Xpeo' => 'persa antic',
        'Xsux' => 'cuneïforme sumeri-accadi',
        'Yiii' => 'yi',
        'Zinh' => 'heretat',
        'Zmth' => 'notació matemàtica',
        'Zsye' => 'emoji',
        'Zsym' => 'símbols',
        'Zxxx' => 'sense escriptura',
        'Zyyy' => 'comú',
    ],
];

==> symfony_7.4.3+dfsg.orig.tar.xz: symfony-7.4.3/src/Symfony/Component/Intl/Resources/data/scripts/ca.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Afak' => 'afaka',
        'Aghb' => 'albanès caucàsic',
        'Ahom' => 'ahom',
        'Arab' => 'àrab',
        'Aran' => 'nasta’liq',
        'Armi' => 'arameu imperial',
        'Armn' => 'armeni',
        'Avst' => 'avèstic',
        'Bali' => 'balinès',
        'Bamu' => 'bamum',
        'Bass' => 'bassa vah',
        'Batk' => 'batak',
        'Beng' => 'bengalí',
        'Bhks' => 'bhaiksuki',
        'Blis' => 'símbols Bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginès',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'sil·labari aborigen canadenc unificat',
        'Cari' => 'carià',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'copte',
        'Cprt' => 'xipriota',
        'Cyrl' => 'ciríl·lic',
        'Cyrs' => 'ciríl·lic de l’antic eslau eclesiàstic',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Dupl' => 'taquigrafia Duployé',
        'Egyd' => 'demòtic egipci',
        'Egyh' => 'hieràtic egipci',
        'Egyp' => 'jeroglífic egipci',
        'Elba' => 'elbasan',
        'Ethi' => 'etiòpic',
        'Geok' => 'georgià hucuri',
        'Geor' => 'georgià',
        'Glag' => 'glagolític',
        'Goth' => 'gòtic',
        'Gran' => 'grantha',
        'Grek' => 'grec',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han amb bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'simplificat',
        'Hant' => 'tradicional',
        'Hebr' => 'hebreu',
        'Hira' => 'hiragana',
        'Hluw' => 'jeroglífic anatoli',
        'Hmng' => 'pahawh hmong',
        'Hrkt' => 'sil·labaris japonesos',
        'Hung' => 'hongarès antic',
        'Inds' => 'escriptura de la vall de l’Indus',
        'Ital' => 'cursiva antiga',
        'Jamo' => 'jamo',
        'Java' => 'javanès',
        'Jpan' => 'japonès',
        'Jurc' => 'jürchen',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharosthi',
        'Khmr' => 'khmer',
        'Khoj' => 'khoja',
        'Knda' => 'kannada',
        'Kore' => 'coreà',
        'Kpel' => 'kpelle',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'lao',
        'Latf' => 'llatí fraktur',
        'Latg' => 'llatí gaèlic',
        'Latn' => 'llatí',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineal A',
        'Linb' => 'lineal B',
        'Lisu' => 'lisu',
        'Loma' => 'loma',
        'Lyci' => 'lici',
        'Lydi' => 'lidi',
        'Mahj' => 'mahajani',
        'Mand' => 'mandaic',
        'Mani' => 'maniqueu',
        'Maya' => 'jeroglífics maies',
        'Mend' => 'mende',
        'Merc' => 'cursiva meroítica',
        'Mero' => 'meroític',
        'Mlym' => 'malaiàlam',
        'Modi' => 'modi',
        'Mong' => 'mongol',
        'Moon' => 'moon',
        'Mroo' => 'mro',
        'Mtei' => 'manipuri',
        'Mult' => 'multani',
        'Mymr' => 'birmà',
        'Narb' => 'antic nord-aràbic',
        'Nbat' => 'nabateu',
        'Newa' => 'newar',
        'Nkgb' => 'geba',
        'Nkoo' => 'n’Ko',
        'Nshu' => 'nü shu',
        'Ogam' => 'ogham',
        'Olck' => 'santali',
        'Orkh' => 'orkhon',
        'Orya' => 'oriya',
        'Osge' => 'osage',
        'Osma' => 'osmanya',
        'Palm' => 'palmirè',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'antic pèrmic',
        'Phag' => 'phagspa',
        'Phli' => 'pahlavi inscripcional',
        'Phlp' => 'psalter pahlavi',
        'Phlv' => 'pahlavi',
        'Phnx' => 'fenici',
        'Plrd' => 'pollard miao',
        'Prti' => 'parthià inscripcional',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Roro' => 'rongo-rongo',
        'Runr' => 'rúnic',
        'Samr' => 'samarità',
        'Sara' => 'sarati',
        'Sarb' => 'sud-aràbic antic',
        'Saur' => 'saurashtra',
        'Sgnw' => 'escriptura de signes',
        'Shaw' => 'shavià',
        'Shrd' => 'shrada',
        'Sidd' => 'siddham',
        'Sind' => 'devangari',
        'Sinh' => 'singalès',
        'Sora' => 'sora sompeng',
        'Sund' => 'sundanès',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siríac',
        'Syre' => 'siríac estrangelo',
        'Syrj' => 'siríac occidental',
        'Syrn' => 'siríac oriental',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'nou tai lue',
        'Taml' => 'tàmil',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinag',
        'Tglg' => 'tagàlog',
        'Thaa' => 'thaana',
        'Thai' => 'tailandès',
        'Tibt' => 'tibetà',
        'Tirh' => 'tirhut',
        'Ugar' => 'ugarític',
        'Vaii' => 'vai',
        'Visp' => 'llenguatge visible',
        'Wara' => 'varang kshiti',
        'Wole' => 'woleai',
        'Xpeo' => 'persa antic',
        'Xsux' => 'cuneïforme sumeri-accadi',
        'Yiii' => 'yi',
        'Zinh' => 'heretat',
        'Zmth' => 'notació matemàtica',
        'Zsye' => 'emoji',
        'Zsym' => 'símbols',
        'Zxxx' => 'sense escriptura',
        'Zyyy' => 'comú',
    ],
];
